[−][src]Crate nix_test_runner
Structs
| TestResult | TestResult of running tests. Contains a field for all passed and failed tests. |
Enums
| Reporter | Reporter used to |
Functions
| run | Evaluates a nix file containing test expressions.
This uses |
| TestResult | TestResult of running tests. Contains a field for all passed and failed tests. |
| Reporter | Reporter used to |
| run | Evaluates a nix file containing test expressions.
This uses |